==> haskell-deferred-folds-0.9.15-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deferred-folds
version:              0.9.15
visibility:           public
id:                   deferred-folds-0.9.15-LgP2QwEJUWC6lQShEw7FPv
key:                  deferred-folds-0.9.15-LgP2QwEJUWC6lQShEw7FPv
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/metrix-ai/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  6a658ad84b36c82a7127f57a668ebc23
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-8.10.3/site-local/deferred-folds-0.9.15
library-dirs:         /usr/lib/ghc-8.10.3/site-local/deferred-folds-0.9.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/deferred-folds-0.9.15
hs-libraries:         HSdeferred-folds-0.9.15-LgP2QwEJUWC6lQShEw7FPv
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    foldl-1.4.10-CvoArDktfsi10A1RCvDKQC
    hashable-1.3.0.0-AuOWFkmW3BKQo2eaHHrrX
    primitive-0.7.1.0-FWMrJqGiHZ5CFbN5KoTYOo text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-GkweYkpoMGZ8mML63K9Z6H
    vector-0.12.1.2-13ERBhpJHs04DSBWSaT2Mz

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deferred-folds-0.9.15-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deferred-folds
version:              0.9.15
visibility:           public
id:                   deferred-folds-0.9.15-CiUTNhYksYFGG8mdrAszD3
key:                  deferred-folds-0.9.15-CiUTNhYksYFGG8mdrAszD3
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/metrix-ai/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  6a109b5d552e5783c901982e2558cc7c
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-8.10.3/site-local/deferred-folds-0.9.15
library-dirs:         /usr/lib/ghc-8.10.3/site-local/deferred-folds-0.9.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/deferred-folds-0.9.15
hs-libraries:         HSdeferred-folds-0.9.15-CiUTNhYksYFGG8mdrAszD3
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    foldl-1.4.10-F4G0R34MaOS1hFRjYZNXsn
    hashable-1.3.0.0-JvDUTigjtBh88bOClrcITG
    primitive-0.7.1.0-BwsxIJTIcWp13XgtTdgayP text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-5ciSEfPtJAO2lGL3MRiwwP
    vector-0.12.1.2-HCJzCvMeU9f2WjtWVmO7dQ

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
